# lunchable

A simple Python SDK around the Lunch Money Developer API

#### This is the documentation branch of lunchable

### [See the Documentation Website](https://juftin.github.io/lunchable)

### [See the Latest Changes](https://github.com/juftin/lunchable)
